@@ -9,8 +9,8 @@ use lib "$FindBin::Bin/../lib";
 use ZeroMQ::PubSub::Server;
 
 my $server = ZeroMQ::PubSub::Server->new(
-    publish_addrs   => [ 'tcp://0.0.0.0:4000', 'ipc:///tmp/pub.sock' ],
-    subscribe_addrs => [ 'tcp://0.0.0.0:5000', 'ipc:///tmp/sub.sock' ],
+    publish_addrs   => [ 'tcp://0.0.0.0:4000', 'ipc:///tmp/0mq_pub.sock' ],
+    subscribe_addrs => [ 'tcp://0.0.0.0:4001', 'ipc:///tmp/0mq_sub.sock' ],
     debug           => 1,
 );
 
